@@ -76,20 +76,20 @@ struct zone_db {
  * \param[in] connection a db_connection_t pointer.
  * \return a zone_db_t pointer or NULL on error.
  */
-zone_db_t* zone_db_new(const db_connection_t* connection);
+extern zone_db_t* zone_db_new(const db_connection_t* connection);
 
 /**
  * Create a new zone object that is a copy of another zone object.
  * \param[in] zone a zone_db_t pointer.
  * \return a zone_db_t pointer or NULL on error.
  */
-zone_db_t* zone_db_new_copy(const zone_db_t* zone);
+extern zone_db_t* zone_db_new_copy(const zone_db_t* zone);
 
 /**
  * Delete a zone object, this does not delete it from the database.
  * \param[in] zone a zone_db_t pointer.
  */
-void zone_db_free(zone_db_t* zone);
+extern void zone_db_free(zone_db_t* zone);
 
 /**
  * Copy the content of a zone object.
@@ -97,7 +97,7 @@ void zone_db_free(zone_db_t* zone);
  * \param[in] zone_copy a zone_db_t pointer.
  * \return DB_ERROR_* on failure, otherwise DB_OK.
  */
-int zone_db_copy(zone_db_t* zone, const zone_db_t* zone_copy);
+extern int zone_db_copy(zone_db_t* zone, const zone_db_t* zone_copy);
 
 /**
  * Set the content of a zone object based on a database result.
@@ -105,21 +105,21 @@ int zone_db_copy(zone_db_t* zone, const zone_db_t* zone_copy);
  * \param[in] result a db_result_t pointer.
  * \return DB_ERROR_* on failure, otherwise DB_OK.
  */
-int zone_db_from_result(zone_db_t* zone, const db_result_t* result);
+extern int zone_db_from_result(zone_db_t* zone, const db_result_t* result);
 
 /**
  * Get the id of a zone object.
  * \param[in] zone a zone_db_t pointer.
  * \return a db_value_t pointer or NULL on error.
  */
-const db_value_t* zone_db_id(const zone_db_t* zone);
+extern const db_value_t* zone_db_id(const zone_db_t* zone);
 
 /**
  * Get the policy_id of a zone object.
  * \param[in] zone a zone_db_t pointer.
  * \return a db_value_t pointer or NULL on error.
  */
-const db_value_t* zone_db_policy_id(const zone_db_t* zone);
+extern const db_value_t* zone_db_policy_id(const zone_db_t* zone);
 
 /**
  * Get the policy_id object related to a zone object.
@@ -127,126 +127,126 @@ const db_value_t* zone_db_policy_id(const zone_db_t* zone);
  * \param[in] zone a zone_db_t pointer.
  * \return a policy_t pointer or NULL on error or if no object could be found.
  */
-policy_t* zone_db_get_policy(const zone_db_t* zone);
+extern policy_t* zone_db_get_policy(const zone_db_t* zone);
 
 /**
  * Get the name of a zone object.
  * \param[in] zone a zone_db_t pointer.
  * \return a character pointer or NULL on error or if no name has been set.
  */
-const char* zone_db_name(const zone_db_t* zone);
+extern const char* zone_db_name(const zone_db_t* zone);
 
 /**
  * Get the signconf_needs_writing of a zone object. Undefined behavior if `zone` is NULL.
  * \param[in] zone a zone_db_t pointer.
  * \return an unsigned integer.
  */
-unsigned int zone_db_signconf_needs_writing(const zone_db_t* zone);
+extern unsigned int zone_db_signconf_needs_writing(const zone_db_t* zone);
 
 /**
  * Get the signconf_path of a zone object.
  * \param[in] zone a zone_db_t pointer.
  * \return a character pointer or NULL on error or if no signconf_path has been set.
  */
-const char* zone_db_signconf_path(const zone_db_t* zone);
+extern const char* zone_db_signconf_path(const zone_db_t* zone);
 
 /**
  * Get the next_change of a zone object. Undefined behavior if `zone` is NULL.
  * \param[in] zone a zone_db_t pointer.
  * \return an integer.
  */
-int zone_db_next_change(const zone_db_t* zone);
+extern int zone_db_next_change(const zone_db_t* zone);
 
 /**
  * Get the ttl_end_ds of a zone object. Undefined behavior if `zone` is NULL.
  * \param[in] zone a zone_db_t pointer.
  * \return an unsigned integer.
  */
-unsigned int zone_db_ttl_end_ds(const zone_db_t* zone);
+extern unsigned int zone_db_ttl_end_ds(const zone_db_t* zone);
 
 /**
  * Get the ttl_end_dk of a zone object. Undefined behavior if `zone` is NULL.
  * \param[in] zone a zone_db_t pointer.
  * \return an unsigned integer.
  */
-unsigned int zone_db_ttl_end_dk(const zone_db_t* zone);
+extern unsigned int zone_db_ttl_end_dk(const zone_db_t* zone);
 
 /**
  * Get the ttl_end_rs of a zone object. Undefined behavior if `zone` is NULL.
  * \param[in] zone a zone_db_t pointer.
  * \return an unsigned integer.
  */
-unsigned int zone_db_ttl_end_rs(const zone_db_t* zone);
+extern unsigned int zone_db_ttl_end_rs(const zone_db_t* zone);
 
 /**
  * Get the roll_ksk_now of a zone object. Undefined behavior if `zone` is NULL.
  * \param[in] zone a zone_db_t pointer.
  * \return an unsigned integer.
  */
-unsigned int zone_db_roll_ksk_now(const zone_db_t* zone);
+extern unsigned int zone_db_roll_ksk_now(const zone_db_t* zone);
 
 /**
  * Get the roll_zsk_now of a zone object. Undefined behavior if `zone` is NULL.
  * \param[in] zone a zone_db_t pointer.
  * \return an unsigned integer.
  */
-unsigned int zone_db_roll_zsk_now(const zone_db_t* zone);
+extern unsigned int zone_db_roll_zsk_now(const zone_db_t* zone);
 
 /**
  * Get the roll_csk_now of a zone object. Undefined behavior if `zone` is NULL.
  * \param[in] zone a zone_db_t pointer.
  * \return an unsigned integer.
  */
-unsigned int zone_db_roll_csk_now(const zone_db_t* zone);
+extern unsigned int zone_db_roll_csk_now(const zone_db_t* zone);
 
 /**
  * Get the input_adapter_type of a zone object.
  * \param[in] zone a zone_db_t pointer.
  * \return a character pointer or NULL on error or if no input_adapter_type has been set.
  */
-const char* zone_db_input_adapter_type(const zone_db_t* zone);
+extern const char* zone_db_input_adapter_type(const zone_db_t* zone);
 
 /**
  * Get the input_adapter_uri of a zone object.
  * \param[in] zone a zone_db_t pointer.
  * \return a character pointer or NULL on error or if no input_adapter_uri has been set.
  */
-const char* zone_db_input_adapter_uri(const zone_db_t* zone);
+extern const char* zone_db_input_adapter_uri(const zone_db_t* zone);
 
 /**
  * Get the output_adapter_type of a zone object.
  * \param[in] zone a zone_db_t pointer.
  * \return a character pointer or NULL on error or if no output_adapter_type has been set.
  */
-const char* zone_db_output_adapter_type(const zone_db_t* zone);
+extern const char* zone_db_output_adapter_type(const zone_db_t* zone);
 
 /**
  * Get the output_adapter_uri of a zone object.
  * \param[in] zone a zone_db_t pointer.
  * \return a character pointer or NULL on error or if no output_adapter_uri has been set.
  */
-const char* zone_db_output_adapter_uri(const zone_db_t* zone);
+extern const char* zone_db_output_adapter_uri(const zone_db_t* zone);
 
 /**
  * Get the next_ksk_roll of a zone object. Undefined behavior if `zone` is NULL.
  * \param[in] zone a zone_db_t pointer.
  * \return an unsigned integer.
  */
-unsigned int zone_db_next_ksk_roll(const zone_db_t* zone);
+extern unsigned int zone_db_next_ksk_roll(const zone_db_t* zone);
 
 /**
  * Get the next_zsk_roll of a zone object. Undefined behavior if `zone` is NULL.
  * \param[in] zone a zone_db_t pointer.
  * \return an unsigned integer.
  */
-unsigned int zone_db_next_zsk_roll(const zone_db_t* zone);
+extern unsigned int zone_db_next_zsk_roll(const zone_db_t* zone);
 
 /**
  * Get the next_csk_roll of a zone object. Undefined behavior if `zone` is NULL.
  * \param[in] zone a zone_db_t pointer.
  * \return an unsigned integer.
  */
-unsigned int zone_db_next_csk_roll(const zone_db_t* zone);
+extern unsigned int zone_db_next_csk_roll(const zone_db_t* zone);
 
 /**
  * Set the policy_id of a zone object. If this fails the original value may have been lost.
@@ -254,7 +254,7 @@ unsigned int zone_db_next_csk_roll(const zone_db_t* zone);
  * \param[in] policy_id a db_value_t pointer.
  * \return DB_ERROR_* on failure, otherwise DB_OK.
  */
-int zone_db_set_policy_id(zone_db_t* zone, const db_value_t* policy_id);
+extern int zone_db_set_policy_id(zone_db_t* zone, const db_value_t* policy_id);
 
 /**
  * Set the name of a zone object.
@@ -262,7 +262,7 @@ int zone_db_set_policy_id(zone_db_t* zone, const db_value_t* policy_id);
  * \param[in] name_text a character pointer.
  * \return DB_ERROR_* on failure, otherwise DB_OK.
  */
-int zone_db_set_name(zone_db_t* zone, const char* name_text);
+extern int zone_db_set_name(zone_db_t* zone, const char* name_text);
 
 /**
  * Set the signconf_needs_writing of a zone object.
@@ -270,7 +270,7 @@ int zone_db_set_name(zone_db_t* zone, const char* name_text);
  * \param[in] signconf_needs_writing an unsigned integer.
  * \return DB_ERROR_* on failure, otherwise DB_OK.
  */
-int zone_db_set_signconf_needs_writing(zone_db_t* zone, unsigned int signconf_needs_writing);
+extern int zone_db_set_signconf_needs_writing(zone_db_t* zone, unsigned int signconf_needs_writing);
 
 /**
  * Set the signconf_path of a zone object.
@@ -278,7 +278,7 @@ int zone_db_set_signconf_needs_writing(zone_db_t* zone, unsigned int signconf_ne
  * \param[in] signconf_path_text a character pointer.
  * \return DB_ERROR_* on failure, otherwise DB_OK.
  */
-int zone_db_set_signconf_path(zone_db_t* zone, const char* signconf_path_text);
+extern int zone_db_set_signconf_path(zone_db_t* zone, const char* signconf_path_text);
 
 /**
  * Set the next_change of a zone object.
@@ -286,7 +286,7 @@ int zone_db_set_signconf_path(zone_db_t* zone, const char* signconf_path_text);
  * \param[in] next_change an integer.
  * \return DB_ERROR_* on failure, otherwise DB_OK.
  */
-int zone_db_set_next_change(zone_db_t* zone, int next_change);
+extern int zone_db_set_next_change(zone_db_t* zone, int next_change);
 
 /**
  * Set the ttl_end_ds of a zone object.
@@ -294,7 +294,7 @@ int zone_db_set_next_change(zone_db_t* zone, int next_change);
  * \param[in] ttl_end_ds an unsigned integer.
  * \return DB_ERROR_* on failure, otherwise DB_OK.
  */
-int zone_db_set_ttl_end_ds(zone_db_t* zone, unsigned int ttl_end_ds);
+extern int zone_db_set_ttl_end_ds(zone_db_t* zone, unsigned int ttl_end_ds);
 
 /**
  * Set the ttl_end_dk of a zone object.
@@ -302,7 +302,7 @@ int zone_db_set_ttl_end_ds(zone_db_t* zone, unsigned int ttl_end_ds);
  * \param[in] ttl_end_dk an unsigned integer.
  * \return DB_ERROR_* on failure, otherwise DB_OK.
  */
-int zone_db_set_ttl_end_dk(zone_db_t* zone, unsigned int ttl_end_dk);
+extern int zone_db_set_ttl_end_dk(zone_db_t* zone, unsigned int ttl_end_dk);
 
 /**
  * Set the ttl_end_rs of a zone object.
@@ -310,7 +310,7 @@ int zone_db_set_ttl_end_dk(zone_db_t* zone, unsigned int ttl_end_dk);
  * \param[in] ttl_end_rs an unsigned integer.
  * \return DB_ERROR_* on failure, otherwise DB_OK.
  */
-int zone_db_set_ttl_end_rs(zone_db_t* zone, unsigned int ttl_end_rs);
+extern int zone_db_set_ttl_end_rs(zone_db_t* zone, unsigned int ttl_end_rs);
 
 /**
  * Set the roll_ksk_now of a zone object.
@@ -318,7 +318,7 @@ int zone_db_set_ttl_end_rs(zone_db_t* zone, unsigned int ttl_end_rs);
  * \param[in] roll_ksk_now an unsigned integer.
  * \return DB_ERROR_* on failure, otherwise DB_OK.
  */
-int zone_db_set_roll_ksk_now(zone_db_t* zone, unsigned int roll_ksk_now);
+extern int zone_db_set_roll_ksk_now(zone_db_t* zone, unsigned int roll_ksk_now);
 
 /**
  * Set the roll_zsk_now of a zone object.
@@ -326,7 +326,7 @@ int zone_db_set_roll_ksk_now(zone_db_t* zone, unsigned int roll_ksk_now);
  * \param[in] roll_zsk_now an unsigned integer.
  * \return DB_ERROR_* on failure, otherwise DB_OK.
  */
-int zone_db_set_roll_zsk_now(zone_db_t* zone, unsigned int roll_zsk_now);
+extern int zone_db_set_roll_zsk_now(zone_db_t* zone, unsigned int roll_zsk_now);
 
 /**
  * Set the roll_csk_now of a zone object.
@@ -334,7 +334,7 @@ int zone_db_set_roll_zsk_now(zone_db_t* zone, unsigned int roll_zsk_now);
  * \param[in] roll_csk_now an unsigned integer.
  * \return DB_ERROR_* on failure, otherwise DB_OK.
  */
-int zone_db_set_roll_csk_now(zone_db_t* zone, unsigned int roll_csk_now);
+extern int zone_db_set_roll_csk_now(zone_db_t* zone, unsigned int roll_csk_now);
 
 /**
  * Set the input_adapter_type of a zone object.
@@ -342,7 +342,7 @@ int zone_db_set_roll_csk_now(zone_db_t* zone, unsigned int roll_csk_now);
  * \param[in] input_adapter_type_text a character pointer.
  * \return DB_ERROR_* on failure, otherwise DB_OK.
  */
-int zone_db_set_input_adapter_type(zone_db_t* zone, const char* input_adapter_type_text);
+extern int zone_db_set_input_adapter_type(zone_db_t* zone, const char* input_adapter_type_text);
 
 /**
  * Set the input_adapter_uri of a zone object.
@@ -350,7 +350,7 @@ int zone_db_set_input_adapter_type(zone_db_t* zone, const char* input_adapter_ty
  * \param[in] input_adapter_uri_text a character pointer.
  * \return DB_ERROR_* on failure, otherwise DB_OK.
  */
-int zone_db_set_input_adapter_uri(zone_db_t* zone, const char* input_adapter_uri_text);
+extern int zone_db_set_input_adapter_uri(zone_db_t* zone, const char* input_adapter_uri_text);
 
 /**
  * Set the output_adapter_type of a zone object.
@@ -358,7 +358,7 @@ int zone_db_set_input_adapter_uri(zone_db_t* zone, const char* input_adapter_uri
  * \param[in] output_adapter_type_text a character pointer.
  * \return DB_ERROR_* on failure, otherwise DB_OK.
  */
-int zone_db_set_output_adapter_type(zone_db_t* zone, const char* output_adapter_type_text);
+extern int zone_db_set_output_adapter_type(zone_db_t* zone, const char* output_adapter_type_text);
 
 /**
  * Set the output_adapter_uri of a zone object.
@@ -366,7 +366,7 @@ int zone_db_set_output_adapter_type(zone_db_t* zone, const char* output_adapter_
  * \param[in] output_adapter_uri_text a character pointer.
  * \return DB_ERROR_* on failure, otherwise DB_OK.
  */
-int zone_db_set_output_adapter_uri(zone_db_t* zone, const char* output_adapter_uri_text);
+extern int zone_db_set_output_adapter_uri(zone_db_t* zone, const char* output_adapter_uri_text);
 
 /**
  * Set the next_ksk_roll of a zone object.
@@ -374,7 +374,7 @@ int zone_db_set_output_adapter_uri(zone_db_t* zone, const char* output_adapter_u
  * \param[in] next_ksk_roll an unsigned integer.
  * \return DB_ERROR_* on failure, otherwise DB_OK.
  */
-int zone_db_set_next_ksk_roll(zone_db_t* zone, unsigned int next_ksk_roll);
+extern int zone_db_set_next_ksk_roll(zone_db_t* zone, unsigned int next_ksk_roll);
 
 /**
  * Set the next_zsk_roll of a zone object.
@@ -382,7 +382,7 @@ int zone_db_set_next_ksk_roll(zone_db_t* zone, unsigned int next_ksk_roll);
  * \param[in] next_zsk_roll an unsigned integer.
  * \return DB_ERROR_* on failure, otherwise DB_OK.
  */
-int zone_db_set_next_zsk_roll(zone_db_t* zone, unsigned int next_zsk_roll);
+extern int zone_db_set_next_zsk_roll(zone_db_t* zone, unsigned int next_zsk_roll);
 
 /**
  * Set the next_csk_roll of a zone object.
@@ -390,7 +390,7 @@ int zone_db_set_next_zsk_roll(zone_db_t* zone, unsigned int next_zsk_roll);
  * \param[in] next_csk_roll an unsigned integer.
  * \return DB_ERROR_* on failure, otherwise DB_OK.
  */
-int zone_db_set_next_csk_roll(zone_db_t* zone, unsigned int next_csk_roll);
+extern int zone_db_set_next_csk_roll(zone_db_t* zone, unsigned int next_csk_roll);
 
 /**
  * Create a clause for policy_id of a zone object and add it to a database clause list.
@@ -401,14 +401,14 @@ int zone_db_set_next_csk_roll(zone_db_t* zone, unsigned int next_csk_roll);
  * \param[in] policy_id a db_value_t pointer.
  * \return a db_clause_t pointer to the added clause or NULL on error.
  */
-db_clause_t* zone_db_policy_id_clause(db_clause_list_t* clause_list, const db_value_t* policy_id);
+extern db_clause_t* zone_db_policy_id_clause(db_clause_list_t* clause_list, const db_value_t* policy_id);
 
 /**
  * Create a zone object in the database.
  * \param[in] zone a zone_db_t pointer.
  * \return DB_ERROR_* on failure, otherwise DB_OK.
  */
-int zone_db_create(zone_db_t* zone);
+extern int zone_db_create(zone_db_t* zone);
 
 /**
  * Get a zone object from the database by a id specified in `id`.
@@ -416,7 +416,7 @@ int zone_db_create(zone_db_t* zone);
  * \param[in] id a db_value_t pointer.
  * \return DB_ERROR_* on failure, otherwise DB_OK.
  */
-int zone_db_get_by_id(zone_db_t* zone, const db_value_t* id);
+extern int zone_db_get_by_id(zone_db_t* zone, const db_value_t* id);
 
 /**
  * Get a zone object from the database by a name specified in `name`.
@@ -424,7 +424,7 @@ int zone_db_get_by_id(zone_db_t* zone, const db_value_t* id);
  * \param[in] name a character pointer.
  * \return DB_ERROR_* on failure, otherwise DB_OK.
  */
-int zone_db_get_by_name(zone_db_t* zone, const char* name);
+extern int zone_db_get_by_name(zone_db_t* zone, const char* name);
 
 /**
  * Get a new zone object from the database by a name specified in `name`.
@@ -432,21 +432,21 @@ int zone_db_get_by_name(zone_db_t* zone, const char* name);
  * \param[in] name a character pointer.
  * \return a zone_db_t pointer or NULL on error or if it does not exist.
  */
-zone_db_t* zone_db_new_get_by_name(const db_connection_t* connection, const char* name);
+extern zone_db_t* zone_db_new_get_by_name(const db_connection_t* connection, const char* name);
 
 /**
  * Update a zone object in the database.
  * \param[in] zone a zone_db_t pointer.
  * \return DB_ERROR_* on failure, otherwise DB_OK.
  */
-int zone_db_update(zone_db_t* zone);
+extern int zone_db_update(zone_db_t* zone);
 
 /**
  * Delete a zone object from the database.
  * \param[in] zone a zone_db_t pointer.
  * \return DB_ERROR_* on failure, otherwise DB_OK.
  */
-int zone_db_delete(zone_db_t* zone);
+extern int zone_db_delete(zone_db_t* zone);
 
 /**
  * Count the number of zone objects in the database, if a selection of
@@ -458,7 +458,7 @@ int zone_db_delete(zone_db_t* zone);
  * should be counted.
  * \return DB_ERROR_* on failure, otherwise DB_OK.
  */
-int zone_db_count(zone_db_t* zone, db_clause_list_t* clause_list, size_t* count);
+extern int zone_db_count(zone_db_t* zone, db_clause_list_t* clause_list, size_t* count);
 
 /**
  * A list of zone objects.
@@ -482,14 +482,14 @@ struct zone_list_db {
  * \param[in] connection a db_connection_t pointer.
  * \return a zone_list_db_t pointer or NULL on error.
  */
-zone_list_db_t* zone_list_db_new(const db_connection_t* connection);
+extern zone_list_db_t* zone_list_db_new(const db_connection_t* connection);
 
 /**
  * Create a new zone object list that is a copy of another.
  * \param[in] zone_list_db a zone_list_db_t pointer.
  * \return a zone_list_db_t pointer or NULL on error.
  */
-zone_list_db_t* zone_list_db_new_copy(const zone_list_db_t* zone_copy);
+extern zone_list_db_t* zone_list_db_new_copy(const zone_list_db_t* zone_copy);
 
 /**
  * Specify that objects should be stored within the list as they are fetch,
@@ -497,13 +497,13 @@ zone_list_db_t* zone_list_db_new_copy(const zone_list_db_t* zone_copy);
  * \param[in] zone_list_db a zone_list_db_t pointer.
  * \return DB_ERROR_* on failure, otherwise DB_OK.
  */
-int zone_list_db_object_store(zone_list_db_t* zone_list_db);
+extern int zone_list_db_object_store(zone_list_db_t* zone_list_db);
 
 /**
  * Delete a zone object list.
  * \param[in] zone_list_db a zone_list_db_t pointer.
  */
-void zone_list_db_free(zone_list_db_t* zone_list_db);
+extern void zone_list_db_free(zone_list_db_t* zone_list_db);
 
 /**
  * Copy the content of another zone object list.
@@ -511,21 +511,21 @@ void zone_list_db_free(zone_list_db_t* zone_list_db);
  * \param[in] from_zone_list_db a zone_list_db_t pointer.
  * \return DB_ERROR_* on failure, otherwise DB_OK.
  */
-int zone_list_db_copy(zone_list_db_t* zone_list_db, const zone_list_db_t* from_zone_list_db);
+extern int zone_list_db_copy(zone_list_db_t* zone_list_db, const zone_list_db_t* from_zone_list_db);
 
 /**
  * Get all zone objects.
  * \param[in] zone_list_db a zone_list_db_t pointer.
  * \return DB_ERROR_* on failure, otherwise DB_OK.
  */
-int zone_list_db_get(zone_list_db_t* zone_list_db);
+extern int zone_list_db_get(zone_list_db_t* zone_list_db);
 
 /**
  * Get a new list with all zone objects.
  * \param[in] connection a db_connection_t pointer.
  * \return a zone_list_db_t pointer or NULL on error.
  */
-zone_list_db_t* zone_list_db_new_get(const db_connection_t* connection);
+extern zone_list_db_t* zone_list_db_new_get(const db_connection_t* connection);
 
 /**
  * Get zone objects from the database by a clause list.
@@ -533,7 +533,7 @@ zone_list_db_t* zone_list_db_new_get(const db_connection_t* connection);
  * \param[in] clause_list a db_clause_list_t pointer.
  * \return DB_ERROR_* on failure, otherwise DB_OK.
  */
-int zone_list_db_get_by_clauses(zone_list_db_t* zone_list_db, const db_clause_list_t* clause_list);
+extern int zone_list_db_get_by_clauses(zone_list_db_t* zone_list_db, const db_clause_list_t* clause_list);
 
 /**
  * Get zone objects from the database by a policy_id specified in `policy_id`.
@@ -541,7 +541,7 @@ int zone_list_db_get_by_clauses(zone_list_db_t* zone_list_db, const db_clause_li
  * \param[in] policy_id a db_value_t pointer.
  * \return DB_ERROR_* on failure, otherwise DB_OK.
  */
-int zone_list_db_get_by_policy_id(zone_list_db_t* zone_list_db, const db_value_t* policy_id);
+extern int zone_list_db_get_by_policy_id(zone_list_db_t* zone_list_db, const db_value_t* policy_id);
 
 /**
  * Get a new list of zone objects from the database by a policy_id specified in `policy_id`.
@@ -549,7 +549,7 @@ int zone_list_db_get_by_policy_id(zone_list_db_t* zone_list_db, const db_value_t
  * \param[in] policy_id a db_value_t pointer.
  * \return a zone_list_db_t pointer or NULL on error.
  */
-zone_list_db_t* zone_list_db_new_get_by_policy_id(const db_connection_t* connection, const db_value_t* policy_id);
+extern zone_list_db_t* zone_list_db_new_get_by_policy_id(const db_connection_t* connection, const db_value_t* policy_id);
 
 /**
  * Get the first zone object in a zone object list and reset the
@@ -558,7 +558,7 @@ zone_list_db_t* zone_list_db_new_get_by_policy_id(const db_connection_t* connect
  * \return a zone_db_t pointer or NULL on error or if there are no
  * zone objects in the zone object list.
  */
-const zone_db_t* zone_list_db_begin(zone_list_db_t* zone_list_db);
+extern const zone_db_t* zone_list_db_begin(zone_list_db_t* zone_list_db);
 
 /**
  * Get the next zone object in a zone object list.
@@ -568,7 +568,7 @@ const zone_db_t* zone_list_db_begin(zone_list_db_t* zone_list_db);
  * \return a zone_db_t pointer or NULL on error or if there are no more
  * zone objects in the zone object list.
  */
-const zone_db_t* zone_list_db_next(zone_list_db_t* zone_list_db);
+extern const zone_db_t* zone_list_db_next(zone_list_db_t* zone_list_db);
 
 /**
  * Get the next zone object in a zone object list.
@@ -578,7 +578,7 @@ const zone_db_t* zone_list_db_next(zone_list_db_t* zone_list_db);
  * \return a zone_db_t pointer or NULL on error or if there are no more
  * zone objects in the zone object list.
  */
-zone_db_t* zone_list_db_get_next(zone_list_db_t* zone_list_db);
+extern zone_db_t* zone_list_db_get_next(zone_list_db_t* zone_list_db);
 
 /**
  * Get the size of a zone object list.
@@ -586,6 +586,6 @@ zone_db_t* zone_list_db_get_next(zone_list_db_t* zone_list_db);
  * \return a size_t with the size of the list or zero on error, if the list is
  * empty or if the backend does not support returning the size.
  */
-size_t zone_list_db_size(zone_list_db_t* zone_list_db);
+extern size_t zone_list_db_size(zone_list_db_t* zone_list_db);
 
 #endif
