@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009 NLNet Labs. All rights reserved.
+ * Copyright (c) 2009-2016 NLNet Labs. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -31,8 +31,8 @@
 
 #include "parser/confparser.h"
 #include "parser/signconfparser.h"
-#include "shared/duration.h"
-#include "shared/log.h"
+#include "duration.h"
+#include "log.h"
 
 #include <libxml/parser.h>
 #include <libxml/xpath.h>
@@ -57,10 +57,12 @@ parse_sc_keys(void* sc, const char* cfgfile)
     xmlChar* xexpr = NULL;
     key_type* new_key = NULL;
     keylist_type* kl = NULL;
-    char* locator = NULL;
-    char* flags = NULL;
-    char* algorithm = NULL;
-    int ksk, zsk, publish, i, rfc5011;
+    char* resourcerecord;
+    char* locator;
+    char* flags;
+    char* algorithm;
+    int configerr;
+    int ksk, zsk, publish, i;
 
     if (!cfgfile || !sc) {
         return NULL;
@@ -95,13 +97,14 @@ parse_sc_keys(void* sc, const char* cfgfile)
     ods_log_assert(kl);
     if (xpathObj->nodesetval && xpathObj->nodesetval->nodeNr > 0) {
         for (i = 0; i < xpathObj->nodesetval->nodeNr; i++) {
+            resourcerecord = NULL;
             locator = NULL;
             flags = NULL;
             algorithm = NULL;
             ksk = 0;
             zsk = 0;
             publish = 0;
-            rfc5011 = 0;
+            configerr = 0;
 
             curNode = xpathObj->nodesetval->nodeTab[i]->xmlChildrenNode;
             while (curNode) {
@@ -117,12 +120,18 @@ parse_sc_keys(void* sc, const char* cfgfile)
                     zsk = 1;
                 } else if (xmlStrEqual(curNode->name, (const xmlChar *)"Publish")) {
                     publish = 1;
-                } else if (xmlStrEqual(curNode->name, (const xmlChar *)"RFC5011")) {
-                    rfc5011 = 1;
+                } else if (xmlStrEqual(curNode->name, (const xmlChar *)"ResourceRecord")) {
+                    resourcerecord = (char *) xmlNodeGetContent(curNode);
                 }
                 curNode = curNode->next;
             }
-            if (locator && algorithm && flags) {
+            if (!algorithm)
+                configerr = 1;
+            if (!flags)
+                configerr = 1;
+            if (!locator && !resourcerecord)
+                configerr = 1;
+            if (!configerr) {
                 /* search for duplicates */
                 new_key = keylist_lookup_by_locator(kl, locator);
                 if (new_key &&
@@ -135,16 +144,15 @@ parse_sc_keys(void* sc, const char* cfgfile)
                     ods_log_warning("[%s] unable to push duplicate key %s "
                         "to keylist, skipping", parser_str, locator);
                 } else {
-                    (void) keylist_push(kl, locator,
+                    (void) keylist_push(kl, locator, resourcerecord,
                         (uint8_t) atoi(algorithm), (uint32_t) atoi(flags),
-                        publish, ksk, zsk, rfc5011);
+                        publish, ksk, zsk);
                 }
             } else {
                 ods_log_error("[%s] unable to push key to keylist: <Key> "
                     "is missing required elements, skipping",
                     parser_str);
             }
-            /* free((void*)locator); */
             free((void*)algorithm);
             free((void*)flags);
         }
@@ -226,6 +234,24 @@ parse_sc_sig_validity_denial(const char* cfgfile)
 }
 
 
+duration_type*
+parse_sc_sig_validity_keyset(const char* cfgfile)
+{
+    duration_type* duration = NULL;
+    const char* str = parse_conf_string(cfgfile,
+        "//SignerConfiguration/Zone/Signatures/Validity/Keyset",
+        0);
+    /* Even if the value is 0 or NULL we want to write it in duration format. 
+       The value is written in backup file and read during startup*/
+    /*if (!str || *str == 0 || *str == '0') {
+        return NULL;
+    }*/
+    duration = duration_create_from_string(str);
+    free((void*)str);
+    return duration;
+}
+
+
 duration_type*
 parse_sc_sig_jitter(const char* cfgfile)
 {
@@ -274,6 +300,66 @@ parse_sc_dnskey_ttl(const char* cfgfile)
 }
 
 
+const char**
+parse_sc_dnskey_sigrrs(const char* cfgfile)
+{
+    xmlDocPtr doc = NULL;
+    xmlXPathContextPtr xpathCtx = NULL;
+    xmlXPathObjectPtr xpathObj = NULL;
+    xmlNode* curNode = NULL;
+    xmlChar* xexpr = NULL;
+    const char **signatureresourcerecords;
+    int i;
+
+    if (!cfgfile) {
+        return NULL;
+    }
+    /* Load XML document */
+    doc = xmlParseFile(cfgfile);
+    if (doc == NULL) {
+        ods_log_error("[%s] unable to parse <Keys>: "
+            "xmlParseFile() failed", parser_str);
+        return NULL;
+    }
+    /* Create xpath evaluation context */
+    xpathCtx = xmlXPathNewContext(doc);
+    if(xpathCtx == NULL) {
+        xmlFreeDoc(doc);
+        ods_log_error("[%s] unable to parse <Keys>: "
+            "xmlXPathNewContext() failed", parser_str);
+        return NULL;
+    }
+    /* Evaluate xpath expression */
+    xexpr = (xmlChar*) "//SignerConfiguration/Zone/Keys/SignatureResourceRecord";
+    xpathObj = xmlXPathEvalExpression(xexpr, xpathCtx);
+    if(xpathObj == NULL) {
+        xmlXPathFreeContext(xpathCtx);
+        xmlFreeDoc(doc);
+        ods_log_error("[%s] unable to parse <Keys>: "
+            "xmlXPathEvalExpression() failed", parser_str);
+        return NULL;
+    }
+    /* Parse keys */
+    if (xpathObj->nodesetval && xpathObj->nodesetval->nodeNr > 0) {
+        signatureresourcerecords = malloc(sizeof(char*) * (xpathObj->nodesetval->nodeNr + 1));
+        for (i = 0; i < xpathObj->nodesetval->nodeNr; i++) {
+            curNode = xpathObj->nodesetval->nodeTab[i];
+            signatureresourcerecords[i] = (char *) xmlNodeGetContent(curNode);
+        }
+        signatureresourcerecords[i] = NULL;
+    } else {
+        signatureresourcerecords = NULL;
+    }
+    xmlXPathFreeObject(xpathObj);
+    xmlXPathFreeContext(xpathCtx);
+    if (doc) {
+        xmlFreeDoc(doc);
+    }
+    return signatureresourcerecords;
+}
+
+
+
 duration_type*
 parse_sc_nsec3param_ttl(const char* cfgfile)
 {
@@ -322,6 +408,22 @@ parse_sc_soa_min(const char* cfgfile)
 }
 
 
+duration_type*
+parse_sc_max_zone_ttl(const char* cfgfile)
+{
+    duration_type* duration = NULL;
+    const char* str = parse_conf_string(cfgfile,
+        "//SignerConfiguration/Zone/Signatures/MaxZoneTTL",
+        0);
+    if (!str) {
+        return NULL;
+    }
+    duration = duration_create_from_string(str);
+    free((void*)str);
+    return duration;
+}
+
+
 /**
  * Parse elements from the configuration file.
  *
@@ -399,13 +501,26 @@ parse_sc_nsec3_optout(const char* cfgfile)
     return ret;
 }
 
+int
+parse_sc_passthrough(const char* cfgfile)
+{
+    int ret = 0;
+    const char* str = parse_conf_string(cfgfile,
+        "//SignerConfiguration/Zone/Passthrough",
+        0);
+    if (str) {
+        ret = 1;
+        free((void*)str);
+    }
+    return ret;
+}
 
 /**
  * Parse elements from the configuration file.
  *
  */
 const char*
-parse_sc_soa_serial(allocator_type* allocator, const char* cfgfile)
+parse_sc_soa_serial(const char* cfgfile)
 {
     const char* dup = NULL;
     const char* str = parse_conf_string(
@@ -414,7 +529,7 @@ parse_sc_soa_serial(allocator_type* allocator, const char* cfgfile)
         1);
 
     if (str) {
-        dup = allocator_strdup(allocator, str);
+        dup = strdup(str);
         free((void*)str);
     }
     return dup;
@@ -422,7 +537,7 @@ parse_sc_soa_serial(allocator_type* allocator, const char* cfgfile)
 
 
 const char*
-parse_sc_nsec3_salt(allocator_type* allocator, const char* cfgfile)
+parse_sc_nsec3_salt(const char* cfgfile)
 {
     const char* dup = NULL;
     const char* str = parse_conf_string(
@@ -431,7 +546,7 @@ parse_sc_nsec3_salt(allocator_type* allocator, const char* cfgfile)
         1);
 
     if (str) {
-        dup = allocator_strdup(allocator, str);
+        dup = strdup(str);
         free((void*)str);
     }
     return dup;
